function love.load()
	love.graphics.setDefaultImageFilter("nearest", "nearest")
	road = love.graphics.newImage("images/road 1.png")
	car = love.graphics.newImage("images/car.png")
	require "libs.class_basic"
		
	const = {	
		width = 320,
		height = 240,
		widthHalf = 160,
		heightHalf = 120,
		
		strips = 120,
		stripSize = 1,
		
		roadWidth = road:getWidth(),
		roadHeight = road:getHeight(),
		carWidth = car:getWidth(),
		carHeight = car:getHeight(),
		
		minimapScale = 6,
		roadScale = 10,
		
		acceleration = 300,
		turnSpeed = 20
	}
	
	roadQuad = love.graphics.newQuad(0, 0, const.roadWidth, const.roadHeight, const.roadWidth, const.roadHeight)
	roadMinimap = love.graphics.newQuad(0, 0, const.roadWidth / const.minimapScale, const.roadHeight / const.minimapScale, const.roadWidth / const.minimapScale, const.roadHeight / const.minimapScale)
		
	time = 0
	rot = 0
	position = { x = const.roadWidth/2, y = const.roadHeight/2 }
	velocity = { l = 0, r = 0 }
	
	stencils = {}
	for i = 1, const.strips do
		stencils[i] = love.graphics.newStencil(function() love.graphics.rectangle("fill", 0, const.heightHalf + i * const.stripSize - const.stripSize, const.width, const.stripSize) end)
	end
	
	love.graphics.setMode(const.width, const.height)
	love.graphics.setBackgroundColor(100, 150, 245)
end

function love.update(dt)
	time = time + dt
	
	if love.keyboard.isDown("w", "up") then
		velocity.l = velocity.l + 400 * dt
	end if love.keyboard.isDown("s", "down") then
		velocity.l = velocity.l - 400 * dt
	end if love.keyboard.isDown("a", "left") then
		velocity.r = velocity.r - 20 * dt
	end if love.keyboard.isDown("d", "right") then
		velocity.r = velocity.r + 20 * dt
	end
		
	velocity.r = velocity.r / (1 + 5 * dt)
	velocity.l = velocity.l / (1 + 2 * dt)
	
	rot = rot + velocity.r * dt
	
	position.x = position.x - velocity.l * math.cos(rot + math.pi / 2) * dt
	position.y = position.y + velocity.l * math.sin(rot + math.pi / 2) * dt
	
	love.graphics.setCaption(love.timer.getFPS())
end

function love.draw()
	for i = 1, const.strips do
		love.graphics.setStencil(stencils[i])
		
		local xscale = (i / const.roadScale)
		local yscale = (i / const.roadScale)
		local alpha = math.min(i * 20, 255)
		--local color = 255
		
		love.graphics.setColor(255, 255, 255, alpha)
		
		love.graphics.drawq(road, roadQuad, const.widthHalf, 0, rot, xscale, yscale, position.x, position.y)
		
		love.graphics.setStencil()
	end
	
	love.graphics.setColor(255, 255, 255)
	love.graphics.drawq(road, roadMinimap, 5, 5)
	love.graphics.setColor(255, 0, 0)
	love.graphics.circle("fill", position.x / const.minimapScale + 5 - 1, position.y / const.minimapScale + 5 - 1, 2)
	love.graphics.line(position.x / const.minimapScale + 5 - 1, position.y / const.minimapScale + 5 - 1, (position.x / const.minimapScale + 5 - 1) + math.sin(rot) * 4, (position.y / const.minimapScale + 5 - 1) + math.cos(rot) * 4)
end

function love.keypressed(key)
	if key == "escape" then love.event.quit() end
end